﻿// Global Settings file "html/NewSettings.js"

// -- This file must exist (cannot be renamed or excluded)
// -- See end of this file for simple one step configuration 


const __is = { // evaluate once 
	HTTP : Boolean(window.location.protocol.substring(0, 4) == "http"),
	Mac : (navigator.platform.indexOf("Mac") === 0 || navigator.platform === "iPhone"),
	favicon : document.querySelector('[rel=icon]'),
	Mobile : Boolean(navigator.userAgent.match(/Android|webOS|iPhone|iPad|iPod|BlackBerry|BB|PlayBook|IEMobile|Mobile|Windows Phone|Kindle|Silk|Opera Mini/i))
}
const __platform = {
	isHTTP : __is.HTTP,
	local : !__is.HTTP,
	isMac : __is.Mac,
	modKey : (__is.Mac) ? "⌘" : "^",
	modKeyPrefix : (__is.Mac) ? "⌘" : "Ctrl+"
}

// path options -- Use one in __GLOBALS.path below
// Note: localThumb -- Set true to find poster and thumb data in a local folder 'videos\thumb' & 'videos\poster' folder
//          set false to thumb/poster located with video folder path
const 
   __PATH_OPTION_AWS = { // Amazon direct path
		media :         'https://s3.ap-southeast-2.amazonaws.com/www.kleckfiles.com/KleckFiles.media/',
		shownotesData : 'https://s3.ap-southeast-2.amazonaws.com/www.kleckfiles.com/KleckFiles.media/shownotes/_data/',
		radio :         'https://s3.ap-southeast-2.amazonaws.com/www.kleckfiles.com/KleckFiles.media/radio/',
		video :         'https://s3.ap-southeast-2.amazonaws.com/www.kleckfiles.com/KleckFiles.media/video/',
		video_mp3 :     'https://s3.ap-southeast-2.amazonaws.com/www.kleckfiles.com/KleckFiles.media/video_mp3/',
		video_thumb :   'https://s3.ap-southeast-2.amazonaws.com/www.kleckfiles.com/KleckFiles.media/video/thumb/', 
		video_poster :  'https://s3.ap-southeast-2.amazonaws.com/www.kleckfiles.com/KleckFiles.media/video/poster/'
	}, 
   __PATH_OPTION_RootFolder = { // Default : root of USB or drive or www.kleckfiles.com
		media :         '/KleckFiles.media/',
		shownotesData : '/KleckFiles.media/shownotes/_data/',
		radio :         '/KleckFiles.media/radio/',
		video :         '/KleckFiles.media/video/',
		video_mp3 :     '/KleckFiles.media/video_mp3/',
		video_thumb :   '/KleckFiles.media/video/thumb/', 
		video_poster :  '/KleckFiles.media/video/poster/'
	}, 
   __PATH_OPTION_SideBySide = {
		media :         '../KleckFiles.media/',
		shownotesData : '../KleckFiles.media/shownotes/_data/',
		radio :         '../KleckFiles.media/radio/',
		video :         '../KleckFiles.media/video/',
		video_mp3 :     '../KleckFiles.media/video_mp3/',
		video_thumb :   '../KleckFiles.media/video/thumb/', 
		video_poster :  '../KleckFiles.media/video/poster/'
	},   
	__PATH_OPTION_Emedded = {
		media :         'KleckFiles.media/',
		shownotesData : 'KleckFiles.media/shownotes/_data/',
		radio :         'KleckFiles.media/radio/',
		video :         'KleckFiles.media/video/',
		video_mp3 :     'KleckFiles.media/video_mp3/',
		video_thumb :   'KleckFiles.media/video/thumb/', 
		video_poster :  'KleckFiles.media/video/poster/'
	},
   __PATH_OPTION_Local = {
		media :         '',
		shownotesData : 'shownotes/_data/',
		radio :         'radio/',
		video :         'video/',
		video_mp3 :     'video_mp3/',
		video_thumb :   'video/thumb/', 
		video_poster :  'video/poster/'
	},
   __PATH_OPTION_RemoteData = {  // kleckfiles.net (uses remote media)
		media :         'http://www.kleckfiles.com/KleckFiles.media/',
		shownotesData : 'http://www.kleckfiles.com/KleckFiles.media/shownotes/_data/',
		radio :         'http://www.kleckfiles.com/KleckFiles.media/radio/',
		video :         'http://www.kleckfiles.com/KleckFiles.media/video/',
		video_mp3 :     'http://www.kleckfiles.com/KleckFiles.media/video_mp3/',
		video_thumb :   'video/thumb/',  // thumbs local 
		video_poster :  'video/poster/'
	}; 
	

var __GLOBALS = {
  debug : false,     // __GLOBALS.debug
  version : "2.01",  // __GLOBALS.version	
	
  path : __PATH_OPTION_RootFolder,   // __GLOBALS.path
	
  // online location of 'video' & 'video/poster' folders
  // webDataPath : 'http://www.kleckfiles.com/',
  webDataPath : 'http://www.kleckfiles.com/KleckFiles.media/',
	
  theEnd : null
};



/* Notes & Inhouse Code -- Ignore
  -- Use forward slashes '/' not backslash '\' in paths for browser web work. '\' is an escape char.
  -- Paths must end with '/' 
  -- Path examples - all these work in Google Chrome. All point to the same location.
    path.shownotes_data = 'file:///E:/shownotes/_data/';	
    path.shownotes_data = 'E:/shownotes/_data/';	
    path.shownotes_data = '../../../../shownotes/_data/';	
    path.shownotes_data = '/shownotes/_data/';
    path.shownotes_data = 'shownotes/_data/';   // local path 


  -- basically FixPaths(); makes '/paths' root paths work in FireFox and Mac browsers
		
  Win local file:///E:/index.html 
  Mac local file:///Volumes/1TB-Kleck3/KleckFiles.media/index.html
  Mac local file:///Users/freddy/Downloads/KleckFiles-3/index.html
  
*/
	
var __GLOBAL_CODE = {
  GetLocalDrive : function() {
	  
	 //example of local path 'file:///D:/path'.split('/')
	 // file:,,,D:,KleckFiles,scribe.html?210617 
	 var path = document.location.href.split('/');

	 if (path.length >= 5 && path[0] == 'file:' && path[1] == '' && path[2] == '') 
	 {
		 if (path[3].length == 2 && path[3].endsWith(':'))  // drive 'D:'
			 return 'file:///' + path[3]; // win 'files:///D:' 

		 if (path[3].toLowerCase() == "volumes") // mac file:///Volumes/ShareName
			 return 'file:///' + path[3] + '/' + path[4]; 
		 
		 if (path[3].toLowerCase() == "users")   // mac file:///Users/freddy
			 return 'file:///' + path[3] + '/' + path[4]; 	
		 
		 if (path[3].length > 0)	             // Linux file:///media/mint/2TB KF Back/
          return 'file:///' + path[3] + '/' + path[4] + '/' + path[5]; 	 

	 }
	  
	 // Special case: 
	 // AWS bucket root = https://s3.ap-southeast-2.amazonaws.com/www.kleckfiles.com/
	  
	 if (path.length >= 4 && path[0] == 'https:' && path[1] == '' && path[2].endsWith('.amazonaws.com') && path[3] == 'www.kleckfiles.com') 
	 {
		 return 'https://' + path[2] + '/' + path[3];
	 }
	  
	 return '';
  },
  
  // fix all paths starting with / (to full expanded path)
  FixPaths : function() {
	 
	 // AWS S3 Bucket root (not using a domain name)
	 // https://s3.ap-southeast-2.amazonaws.com/www.kleckfiles.com/
	 
	 var path = document.location.href.split('/');
	 if (path.length >= 4 && path[0] == 'https:' && path[1] == '' && path[2].endsWith('.amazonaws.com') && path[3] == 'www.kleckfiles.com') 
	 {
		 var awsRoot = 'https://' + path[2] + '/' + path[3] + '/';
		 __GLOBALS.webDataPath = awsRoot + 'KleckFiles.media/'; 		 
	 }
	 
	  
	 // Expand Local paths starting with /
	  
    var drive = __GLOBAL_CODE.GetLocalDrive();  // eg '/E:'
	 if (drive) {
		 
		 if (__GLOBALS.path.media.startsWith('/'))
			  __GLOBALS.path.media = drive + __GLOBALS.path.media;
		 if (__GLOBALS.path.shownotesData.startsWith('/'))
			  __GLOBALS.path.shownotesData = drive + __GLOBALS.path.shownotesData;
		 if (__GLOBALS.path.radio.startsWith('/'))
			  __GLOBALS.path.radio = drive + __GLOBALS.path.radio;
		 if (__GLOBALS.path.video.startsWith('/'))
			  __GLOBALS.path.video = drive + __GLOBALS.path.video;
		 if (__GLOBALS.path.video_mp3.startsWith('/'))
			  __GLOBALS.path.video_mp3 = drive + __GLOBALS.path.video_mp3;
		 if (__GLOBALS.path.video_thumb.startsWith('/'))
			  __GLOBALS.path.video_thumb = drive + __GLOBALS.path.video_thumb;
		 if (__GLOBALS.path.video_poster.startsWith('/'))
			  __GLOBALS.path.video_poster = drive + __GLOBALS.path.video_poster;
		 
	 }
  }
}

__GLOBAL_CODE.FixPaths();
//alert('hello999: '+__GLOBALS.path.video);






// KleckFiles/index.html startup customization settings.
// These settings probably not used anymore 

//__STARTUP__List1_CollapseAll=true;  // default is true. alt set false
//__STARTUP__List2_CollapseAll=true;  // default is true. alst set false

//__STARTUP__List1_Expand=["2011"];  //list of (lowercase!!) folders names to expand on startup eg ["2011", "2012", "2013"]
//__STARTUP__List2_Expand=[0, 1];    //list of playlists indexes to expand on startupeg. [0, 1, 5]

//__STARTUP__PAGETAB=1;           // Startup page -- 1=Videos 2=Playlists

//__SETUP__WEBUNLOCKKEY="";       // In house use -- Web Unlock security Key

//== These 2 No longer used ==
//__STARTUP__YouTubeOverride=0;   // default =0 Set menu > Youtube =ON for web startup only. Set =1 force YouTube ON at startup. Set =2 set OFF at startup (see main menu)
//__STARTUP__ShowMsgBox=0;        // default =0 (program decides when to show startup message). Set=1 to always show. Set=2. Always hide on startup.
